-- ShortSlashCommands V 1.0.0
--
-- (C) 2015 MerlinGer
--

------------------------------------------------
--- Library's
------------------------------------------------
local LAM = LibStub("LibAddonMenu-2.0")

------------------------------------------------
--- Version Informations
------------------------------------------------
ShortSlashCommands = ShortSlashCommands or {}
ShortSlashCommands.AddonId = "SSC_ShortSlashCommands"
ShortSlashCommands.Version = "1.0.0"
ShortSlashCommands.initDone = false
ShortSlashCommandsSave = {}
ShortSlashCommandsSave.cfg = {
	ReloadUI = false,
	Debug = false,
	}

------------------------------------------------
--- Utility functions
------------------------------------------------
local function b(v) if v then return "T" else return "F" end end
local function nn(val) if val == nil then return "NIL" else return val end end
local function dbg(msg) if ShortSlashCommandsSave.cfg.Debug then d("|c999999" .. msg) end end
local function echo(msg) CHAT_SYSTEM.primaryContainer.currentBuffer:AddMessage("|CFFFF00"..msg) end

------------------------------------------------
--- Menu
------------------------------------------------
local function CreateSettingsMenu()
	local panelData = {
		type = "panel",
		name = GetString(SSC_ShortSlashCommands),
		displayName = "|cFFFFB0" .. GetString(SSC_ShortSlashCommands) .. "|r",
		author = "MerlinGer",
		version = ShortSlashCommands.Version,
		slashCommand = "/sscm",
		registerForRefresh = true,
		registerForDefaults = true,
	}
	LAM:RegisterAddonPanel("ShortSlashCommands", panelData)
   
	local optionsTable = {
		{
			type = "header",
			name = GetString(SSC_SETTINGS),
			width = "full",
		},
		{
			type = "checkbox",
			name = GetString(SSC_RELOADUI),
			tooltip = GetString(SSC_RELOADUI_DESC),
			getFunc = function() return ShortSlashCommandsSave.cfg.ReloadUI end,
			setFunc = function(state)
				ShortSlashCommandsSave.cfg.ReloadUI = state
			end,
			default = ShortSlashCommandsSave.cfg[ReloadUI],
		},
		{
			type = "checkbox",
			name = GetString(SSC_DEBUG),
			tooltip = GetString(SSC_DEBUG_DESC),
			getFunc = function() return ShortSlashCommandsSave.cfg.Debug end,
			setFunc = function(state)
				ShortSlashCommandsSave.cfg.Debug = state
			end,
			default = ShortSlashCommandsSave.cfg.Debug,
		},
	}
	LAM:RegisterOptionControls("ShortSlashCommands", optionsTable)
end

------------------------------------------------
--- Initialization
------------------------------------------------
ShortSlashCommandsSave.init = function()
	EVENT_MANAGER:UnregisterForEvent("ShortSlashCommandsInit", EVENT_PLAYER_ACTIVATED)
    -- if ShortSlashCommandsSave.initDone == true then return end
    ShortSlashCommands.initDone = true
    local default = {
		Debug = false,
		ReloadUI = true,
	}
	ShortSlashCommandsSave.cfg = ZO_SavedVars:NewAccountWide("ShortSlashCommands", 1.0, nil, default)
    -- ShortSlashCommandsSave.cfg = ZO_SavedVars:NewAccountWide("ShortSlashCommandsSettings", 1.0, "config", default)
	echo(GetString(SSC_ShortSlashCommands) .. " V " .. ShortSlashCommands.Version .. " " .. GetString(SSC_STARTED) .. ".")
	CreateSettingsMenu()
end

SLASH_COMMANDS["/ssc"] = function()
    echo("ShortSlashCommands Usage")
    echo("  '/rl' - ReloadUI Command")
    return
end

SLASH_COMMANDS["/rl"] = function()
	if ShortSlashCommandsSave.cfg.ReloadUI then
		dbg("|cFF0000ReloadUI ShortSlashCommand: " .. GetString(SSC_ENABLED))
		ReloadUI()
	else
		dbg("|cFF0000ReloadUI ShortSlashCommand: " .. GetString(SSC_DISABLED))
	end
end

EVENT_MANAGER:RegisterForEvent("ShortSlashCommandsInit", EVENT_PLAYER_ACTIVATED, ShortSlashCommandsSave.init)